==========
Changelog
==========

This project adheres to `Semantic Versioning <https://semver.org/>`_.

1.6.0 (2021-11-01)
---------------------------------------------

**Added**

* Introduced command to compute uncertainty of prediction, via the monte-carlo dropout procedure.

* Introduced command to compute input feature importance via the guided grad-cam algorithm, as implemented by the captum lib.

**Fixed**

**Dependencies**

**Deprecated**


1.5.0 (2021-09-01)
---------------------------------------------

**Added**

* First working prototype

**Fixed**

**Dependencies**

**Deprecated**


0.1.0-SNAPSHOT (2021-07-28)
---------------------------------------------

**Added**

* Created the project using mlf-core

**Fixed**

**Dependencies**

**Deprecated**
